@@ -1,8 +1,7 @@
-#!/usr/bin/env python3
-
 from docutils import nodes as _nodes
 from docutils.statemachine import StringList, string2lines
 from importlib import import_module
+from inspect import isclass
 from .errors import ConfigError
 
 
@@ -16,10 +15,10 @@ def pick_class(qual_name, env):
 
     Arguments:
         qual_name (str): The name of the class to pick, or None if the class 
-        should be inferred from the environment.
+            should be inferred from the environment.
         env (sphinx.environment.BuildEnvironment): This object is available as 
-        :attr:`self.env` from :class:`~sphinx.util.docutils.SphinxDirective` 
-        subclasses.
+            :attr:`self.env` from :class:`~sphinx.util.docutils.SphinxDirective` 
+            subclasses.
     """
     if qual_name:
         mod_name, cls_name = qual_name.rsplit('.', 1)
@@ -67,7 +66,7 @@ def pick_sections(sections, exclude=None):
             except KeyError:
                 raise ConfigError(f"no autoclasstoc section with key {x!r}")
 
-        if issubclass(x, Section):
+        if isclass(x) and issubclass(x, Section):
             return x
 
         raise ConfigError(f"cannot interpret {x!r} as a section")
@@ -121,15 +120,16 @@ def make_inherited_details(state, parent, open_by_default=False):
     Make a collapsible node to contain information about inherited attributes.
     """
     from .nodes import details, details_summary
+
     s = details_summary()
-    s += strip_p(nodes_from_rst(state, f"Inherited from :py:class:`{parent.__qualname__}`"))
+    s += strip_p(nodes_from_rst(state, f"Inherited from :py:class:`{get_cls_xref(parent)}`"))
 
     d = details(open_by_default)
     d += s
     return d
 
 
-def make_links(state, attrs):
+def make_links(state, attrs, cls):
     """
     Make links to the given class attributes.
 
@@ -137,20 +137,55 @@ def make_links(state, attrs):
     directive.
     """
     assert attrs
+
+    cls_xref = get_cls_xref(cls, '')
     return nodes_from_rst(state, [
         '.. autosummary::',
         '',
-        *[f'    {x}' for x in attrs],
+        *[f'    {join(cls_xref, x, sep=".")}' for x in attrs],
     ])
 
 
+def get_cls_xref(cls, cant_import=None):
+    """
+    Return a RST-formatted string that references the given class.
+
+    The purpose of this function is to handle the special case where the class 
+    in question can't be imported.  Currently, this case is checked for using a 
+    simple heuristic: whether the class's qualified name includes any local 
+    namespaces.  If this is the case, the return value can be chosen to avoid 
+    triggering any Sphinx/autodoc errors and to produce output that is at least 
+    reasonable.
+    """
+    if '<locals>' in cls.__qualname__:
+        return cls.__name__ if cant_import is None else cant_import
+    else:
+        return f'~{cls.__module__}.{cls.__qualname__}'
+
+
+def find_attrs(cls):
+    """
+    Return a dictionary containing every attribute of the given class.
+
+    This dictionary is very similar to ``__dict__``, except that it also 
+    includes attributes that have annotations but not values.  Such attributes 
+    are assigned the sentinel value `ANNOTATED_ATTR`.
+    """
+    annotated_attrs = {
+            k: ANNOTATED_ATTR
+            for k in getattr(cls, '__annotations__', {})
+            if k not in cls.__dict__
+    }
+    return {**cls.__dict__, **annotated_attrs}
+
+
 def find_inherited_attrs(cls):
     """
     Return a dictionary mapping parent classes to the attributes inherited from 
     those classes.
     """
     return {
-        base: base.__dict__
+        base: find_attrs(base)
         for base in cls.__mro__
         if base not in (cls, object)
     }
@@ -221,3 +256,18 @@ def comma_separated_list(x):
     Parse a restructured text option as a comma-separated list of strings.
     """
     return x.split(',')
+
+
+def join(*strs, sep=''):
+    """
+    Concatenate the given strings, excluding any that are empty.
+    """
+    return sep.join(x for x in strs if x)
+
+ANNOTATED_ATTR = object()
+"""
+A special value used to represent attributes that are annotated, but assigned 
+no value.
+
+This value can appear in the dictionary passed to `filter_attrs()`.
+"""
